@@ -655,12 +655,10 @@
                        2
                        ___goto-table
                        (let* ((u (cadr $1))
-                              (uri (if (and (> (string-length u) 4)
-                                            (equal? (substring u 0 4) "url("))
-                                     (if (equal? (substring u 4 5) "\"")
-                                       (substring u 5 (- (string-length u) 2))
-                                       (substring u 4 (- (string-length u) 1)))
-                                     (substring u 1 (- (string-length u) 1)))))
+                              (uri (if (memv (string-ref u 0)
+                                             '(#\" #\'))
+                                     (substring u 1 (- (string-length u) 1))
+                                     u)))
                          (list (quote @import) uri))
                        ___k))))
                (vector-set!
